@@ -4,7 +4,8 @@ from django.core.management.base import BaseCommand
 from allianceauth.services.hooks import get_extension_logger
 from app_utils.logging import LoggerAddTag
 
-from ... import __title__, constants
+from ... import __title__
+from ...constants import EveCategoryId
 
 logger = LoggerAddTag(get_extension_logger(__name__), __title__)
 
@@ -17,5 +18,5 @@ class Command(BaseCommand):
             "eveuniverse_load_types",
             __title__,
             "--category_id_with_dogma",
-            str(constants.EVE_CATEGORY_ID_STRUCTURE),
+            str(EveCategoryId.STRUCTURE),
         )
